#ifndef UTILITIES_UTILITIES_H
#define UTILITIES_UTILITIES_H

// Weak types
#include "WeakString.h"
#include "WeakVector.h"
#include "WeakMatrix.h"
#include "WeakFactor.h"

// Swap, Min, Max
#include "Algorithms.h"

// Comparison
#include "Comparer.h"

// Memory allocation
#include "New.h"

// Types
#include "Pointer.h"
#include "Buffer.h"
#include "Stack.h"
#include "Vector.h"
#include "Matrix.h"
#include "TriangularMatrix.h"

// Min, Max (vector version), IsSorted
#include "VectorAlgorithms.h"

#endif
